@@ -72,6 +72,7 @@ class Say(object):
     
     options = Options(  
         encoding='utf-8',   # character encoding for output
+        encoded=None,       # character encoding to return
         file=sys.stdout,    # where is output headed? a write() able object, or str
         sep=' ',            # separate args with this (Python print function compatible)
         end='\n',           # end output with this (Python print function compatible)
@@ -171,16 +172,25 @@ class Say(object):
         """
         Do the actual formatting and outputting work. 
         """
+        
+        def encoded(s, encoding):
+            """
+            Encode the strings if they're encoding to be done.
+            """
+            return s.encode(encoding) if encoding else s
 
+        # prepare and emit output
         if opts.end is not None:
             outstr += opts.end
         if not opts.silent:
-            self._write(outstr.encode(opts.encoding), opts)
-        retstr = outstr[:-1] if outstr.endswith('\n') else outstr
-        return retstr
-    
-    # NB writes into encoding, but returns full Unicode
-    
+            self._write(encoded(outstr, opts.encoding), opts)
+            
+        # prepare and return return value
+        retencoding = opts.encoding if opts.encoded is True else opts.encoded
+        retencoded = encoded(outstr, retencoding)
+        rettrimmed = retencoded[:-1] if retencoded.endswith('\n') else retencoded
+        return rettrimmed
+        
     def _output(self, lines, opts):
         """
         Alternate output function that accepts list of lines, not composed strings.
